==> istio-model-v1alpha3-5.11.2-sources.jar: annotations/io/fabric8/istio/api/networking/v1alpha3/SubsetFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class SubsetFluentImpl<A extends io.fabric8.istio.api.networking.v1alpha3.SubsetFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.istio.api.networking.v1alpha3.SubsetFluent<A>{
  public SubsetFluentImpl() {
  }
  public SubsetFluentImpl(io.fabric8.istio.api.networking.v1alpha3.Subset instance) {
    this.withLabels(instance.getLabels()); 
    this.withName(instance.getName()); 
    this.withTrafficPolicy(instance.getTrafficPolicy()); 
  }
  private java.util.Map<java.lang.String,java.lang.String> labels;
  private java.lang.String name;
  private io.fabric8.istio.api.networking.v1alpha3.TrafficPolicyBuilder trafficPolicy;
  public A addToLabels(java.lang.String key,java.lang.String value) {
    if(this.labels == null && key != null && value != null) { this.labels = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(); }
    if(key != null && value != null) {this.labels.put(key, value);} return (A)this;
  }
  public A addToLabels(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.labels == null && map != null) { this.labels = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(); }
    if(map != null) { this.labels.putAll(map);} return (A)this;
  }
  public A removeFromLabels(java.lang.String key) {
    if(this.labels == null) { return (A) this; }
    if(key != null && this.labels != null) {this.labels.remove(key);} return (A)this;
  }
  public A removeFromLabels(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.labels == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.labels != null){this.labels.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.String> getLabels() {
    return this.labels;
  }
  public <K,V>A withLabels(java.util.Map<java.lang.String,java.lang.String> labels) {
    if (labels == null) { this.labels =  null;} else {this.labels = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(labels);} return (A) this;
  }
  public java.lang.Boolean hasLabels() {
    return this.labels != null;
  }
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildTrafficPolicy instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.istio.api.networking.v1alpha3.TrafficPolicy getTrafficPolicy() {
    return this.trafficPolicy!=null?this.trafficPolicy.build():null;
  }
  public io.fabric8.istio.api.networking.v1alpha3.TrafficPolicy buildTrafficPolicy() {
    return this.trafficPolicy!=null?this.trafficPolicy.build():null;
  }
  public A withTrafficPolicy(io.fabric8.istio.api.networking.v1alpha3.TrafficPolicy trafficPolicy) {
    _visitables.get("trafficPolicy").remove(this.trafficPolicy);
    if (trafficPolicy!=null){ this.trafficPolicy= new io.fabric8.istio.api.networking.v1alpha3.TrafficPolicyBuilder(trafficPolicy); _visitables.get("trafficPolicy").add(this.trafficPolicy);} return (A) this;
  }
  public java.lang.Boolean hasTrafficPolicy() {
    return this.trafficPolicy != null;
  }
  public io.fabric8.istio.api.networking.v1alpha3.SubsetFluent.TrafficPolicyNested<A> withNewTrafficPolicy() {
    return new io.fabric8.istio.api.networking.v1alpha3.SubsetFluentImpl.TrafficPolicyNestedImpl();
  }
  public io.fabric8.istio.api.networking.v1alpha3.SubsetFluent.TrafficPolicyNested<A> withNewTrafficPolicyLike(io.fabric8.istio.api.networking.v1alpha3.TrafficPolicy item) {
    return new io.fabric8.istio.api.networking.v1alpha3.SubsetFluentImpl.TrafficPolicyNestedImpl(item);
  }
  public io.fabric8.istio.api.networking.v1alpha3.SubsetFluent.TrafficPolicyNested<A> editTrafficPolicy() {
    return withNewTrafficPolicyLike(getTrafficPolicy());
  }
  public io.fabric8.istio.api.networking.v1alpha3.SubsetFluent.TrafficPolicyNested<A> editOrNewTrafficPolicy() {
    return withNewTrafficPolicyLike(getTrafficPolicy() != null ? getTrafficPolicy(): new io.fabric8.istio.api.networking.v1alpha3.TrafficPolicyBuilder().build());
  }
  public io.fabric8.istio.api.networking.v1alpha3.SubsetFluent.TrafficPolicyNested<A> editOrNewTrafficPolicyLike(io.fabric8.istio.api.networking.v1alpha3.TrafficPolicy item) {
    return withNewTrafficPolicyLike(getTrafficPolicy() != null ? getTrafficPolicy(): item);
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SubsetFluentImpl that = (SubsetFluentImpl) o;
    if (labels != null ? !labels.equals(that.labels) :that.labels != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (trafficPolicy != null ? !trafficPolicy.equals(that.trafficPolicy) :that.trafficPolicy != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(labels,  name,  trafficPolicy,  super.hashCode());
  }
  public class TrafficPolicyNestedImpl<N> extends io.fabric8.istio.api.networking.v1alpha3.TrafficPolicyFluentImpl<io.fabric8.istio.api.networking.v1alpha3.SubsetFluent.TrafficPolicyNested<N>> implements io.fabric8.istio.api.networking.v1alpha3.SubsetFluent.TrafficPolicyNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    TrafficPolicyNestedImpl(io.fabric8.istio.api.networking.v1alpha3.TrafficPolicy item) {
      this.builder = new io.fabric8.istio.api.networking.v1alpha3.TrafficPolicyBuilder(this, item);
    }
    TrafficPolicyNestedImpl() {
      this.builder = new io.fabric8.istio.api.networking.v1alpha3.TrafficPolicyBuilder(this);
    }
    io.fabric8.istio.api.networking.v1alpha3.TrafficPolicyBuilder builder;
    public N and() {
      return (N) SubsetFluentImpl.this.withTrafficPolicy(builder.build());
    }
    public N endTrafficPolicy() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-5.12.3-sources.jar: annotations/io/fabric8/istio/api/networking/v1alpha3/SubsetFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class SubsetFluentImpl<A extends io.fabric8.istio.api.networking.v1alpha3.SubsetFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.istio.api.networking.v1alpha3.SubsetFluent<A>{
  public SubsetFluentImpl() {
  }
  public SubsetFluentImpl(io.fabric8.istio.api.networking.v1alpha3.Subset instance) {
    this.withLabels(instance.getLabels()); 
    this.withName(instance.getName()); 
    this.withTrafficPolicy(instance.getTrafficPolicy()); 
  }
  private java.util.Map<java.lang.String,java.lang.String> labels;
  private java.lang.String name;
  private io.fabric8.istio.api.networking.v1alpha3.TrafficPolicyBuilder trafficPolicy;
  public A addToLabels(java.lang.String key,java.lang.String value) {
    if(this.labels == null && key != null && value != null) { this.labels = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.labels.put(key, value);} return (A)this;
  }
  public A addToLabels(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.labels == null && map != null) { this.labels = new java.util.LinkedHashMap(); }
    if(map != null) { this.labels.putAll(map);} return (A)this;
  }
  public A removeFromLabels(java.lang.String key) {
    if(this.labels == null) { return (A) this; }
    if(key != null && this.labels != null) {this.labels.remove(key);} return (A)this;
  }
  public A removeFromLabels(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.labels == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.labels != null){this.labels.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.String> getLabels() {
    return this.labels;
  }
  public <K,V>A withLabels(java.util.Map<java.lang.String,java.lang.String> labels) {
    if (labels == null) { this.labels =  null;} else {this.labels = new java.util.LinkedHashMap(labels);} return (A) this;
  }
  public java.lang.Boolean hasLabels() {
    return this.labels != null;
  }
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildTrafficPolicy instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.istio.api.networking.v1alpha3.TrafficPolicy getTrafficPolicy() {
    return this.trafficPolicy!=null?this.trafficPolicy.build():null;
  }
  public io.fabric8.istio.api.networking.v1alpha3.TrafficPolicy buildTrafficPolicy() {
    return this.trafficPolicy!=null?this.trafficPolicy.build():null;
  }
  public A withTrafficPolicy(io.fabric8.istio.api.networking.v1alpha3.TrafficPolicy trafficPolicy) {
    _visitables.get("trafficPolicy").remove(this.trafficPolicy);
    if (trafficPolicy!=null){ this.trafficPolicy= new io.fabric8.istio.api.networking.v1alpha3.TrafficPolicyBuilder(trafficPolicy); _visitables.get("trafficPolicy").add(this.trafficPolicy);} return (A) this;
  }
  public java.lang.Boolean hasTrafficPolicy() {
    return this.trafficPolicy != null;
  }
  public io.fabric8.istio.api.networking.v1alpha3.SubsetFluent.TrafficPolicyNested<A> withNewTrafficPolicy() {
    return new io.fabric8.istio.api.networking.v1alpha3.SubsetFluentImpl.TrafficPolicyNestedImpl();
  }
  public io.fabric8.istio.api.networking.v1alpha3.SubsetFluent.TrafficPolicyNested<A> withNewTrafficPolicyLike(io.fabric8.istio.api.networking.v1alpha3.TrafficPolicy item) {
    return new io.fabric8.istio.api.networking.v1alpha3.SubsetFluentImpl.TrafficPolicyNestedImpl(item);
  }
  public io.fabric8.istio.api.networking.v1alpha3.SubsetFluent.TrafficPolicyNested<A> editTrafficPolicy() {
    return withNewTrafficPolicyLike(getTrafficPolicy());
  }
  public io.fabric8.istio.api.networking.v1alpha3.SubsetFluent.TrafficPolicyNested<A> editOrNewTrafficPolicy() {
    return withNewTrafficPolicyLike(getTrafficPolicy() != null ? getTrafficPolicy(): new io.fabric8.istio.api.networking.v1alpha3.TrafficPolicyBuilder().build());
  }
  public io.fabric8.istio.api.networking.v1alpha3.SubsetFluent.TrafficPolicyNested<A> editOrNewTrafficPolicyLike(io.fabric8.istio.api.networking.v1alpha3.TrafficPolicy item) {
    return withNewTrafficPolicyLike(getTrafficPolicy() != null ? getTrafficPolicy(): item);
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SubsetFluentImpl that = (SubsetFluentImpl) o;
    if (labels != null ? !labels.equals(that.labels) :that.labels != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (trafficPolicy != null ? !trafficPolicy.equals(that.trafficPolicy) :that.trafficPolicy != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(labels,  name,  trafficPolicy,  super.hashCode());
  }
  public class TrafficPolicyNestedImpl<N> extends io.fabric8.istio.api.networking.v1alpha3.TrafficPolicyFluentImpl<io.fabric8.istio.api.networking.v1alpha3.SubsetFluent.TrafficPolicyNested<N>> implements io.fabric8.istio.api.networking.v1alpha3.SubsetFluent.TrafficPolicyNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    TrafficPolicyNestedImpl(io.fabric8.istio.api.networking.v1alpha3.TrafficPolicy item) {
      this.builder = new io.fabric8.istio.api.networking.v1alpha3.TrafficPolicyBuilder(this, item);
    }
    TrafficPolicyNestedImpl() {
      this.builder = new io.fabric8.istio.api.networking.v1alpha3.TrafficPolicyBuilder(this);
    }
    io.fabric8.istio.api.networking.v1alpha3.TrafficPolicyBuilder builder;
    public N and() {
      return (N) SubsetFluentImpl.this.withTrafficPolicy(builder.build());
    }
    public N endTrafficPolicy() {
      return and();
    }
    
  }
  
}
